# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: zeebe_grpc/gateway.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18zeebe_grpc/gateway.proto\x12\x10gateway_protocol\"\x8e\x01\n\x13\x41\x63tivateJobsRequest\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0e\n\x06worker\x18\x02 \x01(\t\x12\x0f\n\x07timeout\x18\x03 \x01(\x03\x12\x19\n\x11maxJobsToActivate\x18\x04 \x01(\x05\x12\x15\n\rfetchVariable\x18\x05 \x03(\t\x12\x16\n\x0erequestTimeout\x18\x06 \x01(\x03\"D\n\x14\x41\x63tivateJobsResponse\x12,\n\x04jobs\x18\x01 \x03(\x0b\x32\x1e.gateway_protocol.ActivatedJob\"\xa8\x02\n\x0c\x41\x63tivatedJob\x12\x0b\n\x03key\x18\x01 \x01(\x03\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x1a\n\x12processInstanceKey\x18\x03 \x01(\x03\x12\x15\n\rbpmnProcessId\x18\x04 \x01(\t\x12 \n\x18processDefinitionVersion\x18\x05 \x01(\x05\x12\x1c\n\x14processDefinitionKey\x18\x06 \x01(\x03\x12\x11\n\telementId\x18\x07 \x01(\t\x12\x1a\n\x12\x65lementInstanceKey\x18\x08 \x01(\x03\x12\x15\n\rcustomHeaders\x18\t \x01(\t\x12\x0e\n\x06worker\x18\n \x01(\t\x12\x0f\n\x07retries\x18\x0b \x01(\x05\x12\x10\n\x08\x64\x65\x61\x64line\x18\x0c \x01(\x03\x12\x11\n\tvariables\x18\r \x01(\t\":\n\x1c\x43\x61ncelProcessInstanceRequest\x12\x1a\n\x12processInstanceKey\x18\x01 \x01(\x03\"\x1f\n\x1d\x43\x61ncelProcessInstanceResponse\"7\n\x12\x43ompleteJobRequest\x12\x0e\n\x06jobKey\x18\x01 \x01(\x03\x12\x11\n\tvariables\x18\x02 \x01(\t\"\x15\n\x13\x43ompleteJobResponse\"w\n\x1c\x43reateProcessInstanceRequest\x12\x1c\n\x14processDefinitionKey\x18\x01 \x01(\x03\x12\x15\n\rbpmnProcessId\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\x05\x12\x11\n\tvariables\x18\x04 \x01(\t\"\x81\x01\n\x1d\x43reateProcessInstanceResponse\x12\x1c\n\x14processDefinitionKey\x18\x01 \x01(\x03\x12\x15\n\rbpmnProcessId\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\x05\x12\x1a\n\x12processInstanceKey\x18\x04 \x01(\x03\"\x99\x01\n&CreateProcessInstanceWithResultRequest\x12?\n\x07request\x18\x01 \x01(\x0b\x32..gateway_protocol.CreateProcessInstanceRequest\x12\x16\n\x0erequestTimeout\x18\x02 \x01(\x03\x12\x16\n\x0e\x66\x65tchVariables\x18\x03 \x03(\t\"\x9e\x01\n\'CreateProcessInstanceWithResultResponse\x12\x1c\n\x14processDefinitionKey\x18\x01 \x01(\x03\x12\x15\n\rbpmnProcessId\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\x05\x12\x1a\n\x12processInstanceKey\x18\x04 \x01(\x03\x12\x11\n\tvariables\x18\x05 \x01(\t\"U\n\x14\x44\x65ployProcessRequest\x12\x39\n\tprocesses\x18\x01 \x03(\x0b\x32&.gateway_protocol.ProcessRequestObject:\x02\x18\x01\"<\n\x14ProcessRequestObject\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\ndefinition\x18\x02 \x01(\x0c:\x02\x18\x01\"^\n\x15\x44\x65ployProcessResponse\x12\x0b\n\x03key\x18\x01 \x01(\x03\x12\x34\n\tprocesses\x18\x02 \x03(\x0b\x32!.gateway_protocol.ProcessMetadata:\x02\x18\x01\"F\n\x15\x44\x65ployResourceRequest\x12-\n\tresources\x18\x01 \x03(\x0b\x32\x1a.gateway_protocol.Resource\")\n\x08Resource\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\x0c\"X\n\x16\x44\x65ployResourceResponse\x12\x0b\n\x03key\x18\x01 \x01(\x03\x12\x31\n\x0b\x64\x65ployments\x18\x02 \x03(\x0b\x32\x1c.gateway_protocol.Deployment\"\xd6\x01\n\nDeployment\x12\x34\n\x07process\x18\x01 \x01(\x0b\x32!.gateway_protocol.ProcessMetadataH\x00\x12\x36\n\x08\x64\x65\x63ision\x18\x02 \x01(\x0b\x32\".gateway_protocol.DecisionMetadataH\x00\x12N\n\x14\x64\x65\x63isionRequirements\x18\x03 \x01(\x0b\x32..gateway_protocol.DecisionRequirementsMetadataH\x00\x42\n\n\x08Metadata\"m\n\x0fProcessMetadata\x12\x15\n\rbpmnProcessId\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\x05\x12\x1c\n\x14processDefinitionKey\x18\x03 \x01(\x03\x12\x14\n\x0cresourceName\x18\x04 \x01(\t\"\xac\x01\n\x10\x44\x65\x63isionMetadata\x12\x15\n\rdmnDecisionId\x18\x01 \x01(\t\x12\x17\n\x0f\x64mnDecisionName\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\x05\x12\x13\n\x0b\x64\x65\x63isionKey\x18\x04 \x01(\x03\x12!\n\x19\x64mnDecisionRequirementsId\x18\x05 \x01(\t\x12\x1f\n\x17\x64\x65\x63isionRequirementsKey\x18\x06 \x01(\x03\"\xae\x01\n\x1c\x44\x65\x63isionRequirementsMetadata\x12!\n\x19\x64mnDecisionRequirementsId\x18\x01 \x01(\t\x12#\n\x1b\x64mnDecisionRequirementsName\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\x05\x12\x1f\n\x17\x64\x65\x63isionRequirementsKey\x18\x04 \x01(\x03\x12\x14\n\x0cresourceName\x18\x05 \x01(\t\"]\n\x0e\x46\x61ilJobRequest\x12\x0e\n\x06jobKey\x18\x01 \x01(\x03\x12\x0f\n\x07retries\x18\x02 \x01(\x05\x12\x14\n\x0c\x65rrorMessage\x18\x03 \x01(\t\x12\x14\n\x0cretryBackOff\x18\x04 \x01(\x03\"\x11\n\x0f\x46\x61ilJobResponse\"L\n\x11ThrowErrorRequest\x12\x0e\n\x06jobKey\x18\x01 \x01(\x03\x12\x11\n\terrorCode\x18\x02 \x01(\t\x12\x14\n\x0c\x65rrorMessage\x18\x03 \x01(\t\"\x14\n\x12ThrowErrorResponse\"w\n\x15PublishMessageRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x16\n\x0e\x63orrelationKey\x18\x02 \x01(\t\x12\x12\n\ntimeToLive\x18\x03 \x01(\x03\x12\x11\n\tmessageId\x18\x04 \x01(\t\x12\x11\n\tvariables\x18\x05 \x01(\t\"%\n\x16PublishMessageResponse\x12\x0b\n\x03key\x18\x01 \x01(\x03\"-\n\x16ResolveIncidentRequest\x12\x13\n\x0bincidentKey\x18\x01 \x01(\x03\"\x19\n\x17ResolveIncidentResponse\"\x11\n\x0fTopologyRequest\"\xa2\x01\n\x10TopologyResponse\x12-\n\x07\x62rokers\x18\x01 \x03(\x0b\x32\x1c.gateway_protocol.BrokerInfo\x12\x13\n\x0b\x63lusterSize\x18\x02 \x01(\x05\x12\x17\n\x0fpartitionsCount\x18\x03 \x01(\x05\x12\x19\n\x11replicationFactor\x18\x04 \x01(\x05\x12\x16\n\x0egatewayVersion\x18\x05 \x01(\t\"z\n\nBrokerInfo\x12\x0e\n\x06nodeId\x18\x01 \x01(\x05\x12\x0c\n\x04host\x18\x02 \x01(\t\x12\x0c\n\x04port\x18\x03 \x01(\x05\x12/\n\npartitions\x18\x04 \x03(\x0b\x32\x1b.gateway_protocol.Partition\x12\x0f\n\x07version\x18\x05 \x01(\t\"\xa0\x02\n\tPartition\x12\x13\n\x0bpartitionId\x18\x01 \x01(\x05\x12=\n\x04role\x18\x02 \x01(\x0e\x32/.gateway_protocol.Partition.PartitionBrokerRole\x12\x41\n\x06health\x18\x03 \x01(\x0e\x32\x31.gateway_protocol.Partition.PartitionBrokerHealth\"=\n\x13PartitionBrokerRole\x12\n\n\x06LEADER\x10\x00\x12\x0c\n\x08\x46OLLOWER\x10\x01\x12\x0c\n\x08INACTIVE\x10\x02\"=\n\x15PartitionBrokerHealth\x12\x0b\n\x07HEALTHY\x10\x00\x12\r\n\tUNHEALTHY\x10\x01\x12\x08\n\x04\x44\x45\x41\x44\x10\x02\":\n\x17UpdateJobRetriesRequest\x12\x0e\n\x06jobKey\x18\x01 \x01(\x03\x12\x0f\n\x07retries\x18\x02 \x01(\x05\"\x1a\n\x18UpdateJobRetriesResponse\"S\n\x13SetVariablesRequest\x12\x1a\n\x12\x65lementInstanceKey\x18\x01 \x01(\x03\x12\x11\n\tvariables\x18\x02 \x01(\t\x12\r\n\x05local\x18\x03 \x01(\x08\"#\n\x14SetVariablesResponse\x12\x0b\n\x03key\x18\x01 \x01(\x03\x32\xcc\x0b\n\x07Gateway\x12\x61\n\x0c\x41\x63tivateJobs\x12%.gateway_protocol.ActivateJobsRequest\x1a&.gateway_protocol.ActivateJobsResponse\"\x00\x30\x01\x12z\n\x15\x43\x61ncelProcessInstance\x12..gateway_protocol.CancelProcessInstanceRequest\x1a/.gateway_protocol.CancelProcessInstanceResponse\"\x00\x12\\\n\x0b\x43ompleteJob\x12$.gateway_protocol.CompleteJobRequest\x1a%.gateway_protocol.CompleteJobResponse\"\x00\x12z\n\x15\x43reateProcessInstance\x12..gateway_protocol.CreateProcessInstanceRequest\x1a/.gateway_protocol.CreateProcessInstanceResponse\"\x00\x12\x98\x01\n\x1f\x43reateProcessInstanceWithResult\x12\x38.gateway_protocol.CreateProcessInstanceWithResultRequest\x1a\x39.gateway_protocol.CreateProcessInstanceWithResultResponse\"\x00\x12\x65\n\rDeployProcess\x12&.gateway_protocol.DeployProcessRequest\x1a\'.gateway_protocol.DeployProcessResponse\"\x03\x88\x02\x01\x12\x65\n\x0e\x44\x65ployResource\x12\'.gateway_protocol.DeployResourceRequest\x1a(.gateway_protocol.DeployResourceResponse\"\x00\x12P\n\x07\x46\x61ilJob\x12 .gateway_protocol.FailJobRequest\x1a!.gateway_protocol.FailJobResponse\"\x00\x12Y\n\nThrowError\x12#.gateway_protocol.ThrowErrorRequest\x1a$.gateway_protocol.ThrowErrorResponse\"\x00\x12\x65\n\x0ePublishMessage\x12\'.gateway_protocol.PublishMessageRequest\x1a(.gateway_protocol.PublishMessageResponse\"\x00\x12h\n\x0fResolveIncident\x12(.gateway_protocol.ResolveIncidentRequest\x1a).gateway_protocol.ResolveIncidentResponse\"\x00\x12_\n\x0cSetVariables\x12%.gateway_protocol.SetVariablesRequest\x1a&.gateway_protocol.SetVariablesResponse\"\x00\x12S\n\x08Topology\x12!.gateway_protocol.TopologyRequest\x1a\".gateway_protocol.TopologyResponse\"\x00\x12k\n\x10UpdateJobRetries\x12).gateway_protocol.UpdateJobRetriesRequest\x1a*.gateway_protocol.UpdateJobRetriesResponse\"\x00\x42,\n!io.camunda.zeebe.gateway.protocolP\x00Z\x05./;pbb\x06proto3')



_ACTIVATEJOBSREQUEST = DESCRIPTOR.message_types_by_name['ActivateJobsRequest']
_ACTIVATEJOBSRESPONSE = DESCRIPTOR.message_types_by_name['ActivateJobsResponse']
_ACTIVATEDJOB = DESCRIPTOR.message_types_by_name['ActivatedJob']
_CANCELPROCESSINSTANCEREQUEST = DESCRIPTOR.message_types_by_name['CancelProcessInstanceRequest']
_CANCELPROCESSINSTANCERESPONSE = DESCRIPTOR.message_types_by_name['CancelProcessInstanceResponse']
_COMPLETEJOBREQUEST = DESCRIPTOR.message_types_by_name['CompleteJobRequest']
_COMPLETEJOBRESPONSE = DESCRIPTOR.message_types_by_name['CompleteJobResponse']
_CREATEPROCESSINSTANCEREQUEST = DESCRIPTOR.message_types_by_name['CreateProcessInstanceRequest']
_CREATEPROCESSINSTANCERESPONSE = DESCRIPTOR.message_types_by_name['CreateProcessInstanceResponse']
_CREATEPROCESSINSTANCEWITHRESULTREQUEST = DESCRIPTOR.message_types_by_name['CreateProcessInstanceWithResultRequest']
_CREATEPROCESSINSTANCEWITHRESULTRESPONSE = DESCRIPTOR.message_types_by_name['CreateProcessInstanceWithResultResponse']
_DEPLOYPROCESSREQUEST = DESCRIPTOR.message_types_by_name['DeployProcessRequest']
_PROCESSREQUESTOBJECT = DESCRIPTOR.message_types_by_name['ProcessRequestObject']
_DEPLOYPROCESSRESPONSE = DESCRIPTOR.message_types_by_name['DeployProcessResponse']
_DEPLOYRESOURCEREQUEST = DESCRIPTOR.message_types_by_name['DeployResourceRequest']
_RESOURCE = DESCRIPTOR.message_types_by_name['Resource']
_DEPLOYRESOURCERESPONSE = DESCRIPTOR.message_types_by_name['DeployResourceResponse']
_DEPLOYMENT = DESCRIPTOR.message_types_by_name['Deployment']
_PROCESSMETADATA = DESCRIPTOR.message_types_by_name['ProcessMetadata']
_DECISIONMETADATA = DESCRIPTOR.message_types_by_name['DecisionMetadata']
_DECISIONREQUIREMENTSMETADATA = DESCRIPTOR.message_types_by_name['DecisionRequirementsMetadata']
_FAILJOBREQUEST = DESCRIPTOR.message_types_by_name['FailJobRequest']
_FAILJOBRESPONSE = DESCRIPTOR.message_types_by_name['FailJobResponse']
_THROWERRORREQUEST = DESCRIPTOR.message_types_by_name['ThrowErrorRequest']
_THROWERRORRESPONSE = DESCRIPTOR.message_types_by_name['ThrowErrorResponse']
_PUBLISHMESSAGEREQUEST = DESCRIPTOR.message_types_by_name['PublishMessageRequest']
_PUBLISHMESSAGERESPONSE = DESCRIPTOR.message_types_by_name['PublishMessageResponse']
_RESOLVEINCIDENTREQUEST = DESCRIPTOR.message_types_by_name['ResolveIncidentRequest']
_RESOLVEINCIDENTRESPONSE = DESCRIPTOR.message_types_by_name['ResolveIncidentResponse']
_TOPOLOGYREQUEST = DESCRIPTOR.message_types_by_name['TopologyRequest']
_TOPOLOGYRESPONSE = DESCRIPTOR.message_types_by_name['TopologyResponse']
_BROKERINFO = DESCRIPTOR.message_types_by_name['BrokerInfo']
_PARTITION = DESCRIPTOR.message_types_by_name['Partition']
_UPDATEJOBRETRIESREQUEST = DESCRIPTOR.message_types_by_name['UpdateJobRetriesRequest']
_UPDATEJOBRETRIESRESPONSE = DESCRIPTOR.message_types_by_name['UpdateJobRetriesResponse']
_SETVARIABLESREQUEST = DESCRIPTOR.message_types_by_name['SetVariablesRequest']
_SETVARIABLESRESPONSE = DESCRIPTOR.message_types_by_name['SetVariablesResponse']
_PARTITION_PARTITIONBROKERROLE = _PARTITION.enum_types_by_name['PartitionBrokerRole']
_PARTITION_PARTITIONBROKERHEALTH = _PARTITION.enum_types_by_name['PartitionBrokerHealth']
ActivateJobsRequest = _reflection.GeneratedProtocolMessageType('ActivateJobsRequest', (_message.Message,), {
  'DESCRIPTOR' : _ACTIVATEJOBSREQUEST,
  '__module__' : 'zeebe_grpc.gateway_pb2'
  # @@protoc_insertion_point(class_scope:gateway_protocol.ActivateJobsRequest)
  })
_sym_db.RegisterMessage(ActivateJobsRequest)

ActivateJobsResponse = _reflection.GeneratedProtocolMessageType('ActivateJobsResponse', (_message.Message,), {
  'DESCRIPTOR' : _ACTIVATEJOBSRESPONSE,
  '__module__' : 'zeebe_grpc.gateway_pb2'
  # @@protoc_insertion_point(class_scope:gateway_protocol.ActivateJobsResponse)
  })
_sym_db.RegisterMessage(ActivateJobsResponse)

ActivatedJob = _reflection.GeneratedProtocolMessageType('ActivatedJob', (_message.Message,), {
  'DESCRIPTOR' : _ACTIVATEDJOB,
  '__module__' : 'zeebe_grpc.gateway_pb2'
  # @@protoc_insertion_point(class_scope:gateway_protocol.ActivatedJob)
  })
_sym_db.RegisterMessage(ActivatedJob)

CancelProcessInstanceRequest = _reflection.GeneratedProtocolMessageType('CancelProcessInstanceRequest', (_message.Message,), {
  'DESCRIPTOR' : _CANCELPROCESSINSTANCEREQUEST,
  '__module__' : 'zeebe_grpc.gateway_pb2'
  # @@protoc_insertion_point(class_scope:gateway_protocol.CancelProcessInstanceRequest)
  })
_sym_db.RegisterMessage(CancelProcessInstanceRequest)

CancelProcessInstanceResponse = _reflection.GeneratedProtocolMessageType('CancelProcessInstanceResponse', (_message.Message,), {
  'DESCRIPTOR' : _CANCELPROCESSINSTANCERESPONSE,
  '__module__' : 'zeebe_grpc.gateway_pb2'
  # @@protoc_insertion_point(class_scope:gateway_protocol.CancelProcessInstanceResponse)
  })
_sym_db.RegisterMessage(CancelProcessInstanceResponse)

CompleteJobRequest = _reflection.GeneratedProtocolMessageType('CompleteJobRequest', (_message.Message,), {
  'DESCRIPTOR' : _COMPLETEJOBREQUEST,
  '__module__' : 'zeebe_grpc.gateway_pb2'
  # @@protoc_insertion_point(class_scope:gateway_protocol.CompleteJobRequest)
  })
_sym_db.RegisterMessage(CompleteJobRequest)

CompleteJobResponse = _reflection.GeneratedProtocolMessageType('CompleteJobResponse', (_message.Message,), {
  'DESCRIPTOR' : _COMPLETEJOBRESPONSE,
  '__module__' : 'zeebe_grpc.gateway_pb2'
  # @@protoc_insertion_point(class_scope:gateway_protocol.CompleteJobResponse)
  })
_sym_db.RegisterMessage(CompleteJobResponse)

CreateProcessInstanceRequest = _reflection.GeneratedProtocolMessageType('CreateProcessInstanceRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPROCESSINSTANCEREQUEST,
  '__module__' : 'zeebe_grpc.gateway_pb2'
  # @@protoc_insertion_point(class_scope:gateway_protocol.CreateProcessInstanceRequest)
  })
_sym_db.RegisterMessage(CreateProcessInstanceRequest)

CreateProcessInstanceResponse = _reflection.GeneratedProtocolMessageType('CreateProcessInstanceResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPROCESSINSTANCERESPONSE,
  '__module__' : 'zeebe_grpc.gateway_pb2'
  # @@protoc_insertion_point(class_scope:gateway_protocol.CreateProcessInstanceResponse)
  })
_sym_db.RegisterMessage(CreateProcessInstanceResponse)

CreateProcessInstanceWithResultRequest = _reflection.GeneratedProtocolMessageType('CreateProcessInstanceWithResultRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPROCESSINSTANCEWITHRESULTREQUEST,
  '__module__' : 'zeebe_grpc.gateway_pb2'
  # @@protoc_insertion_point(class_scope:gateway_protocol.CreateProcessInstanceWithResultRequest)
  })
_sym_db.RegisterMessage(CreateProcessInstanceWithResultRequest)

CreateProcessInstanceWithResultResponse = _reflection.GeneratedProtocolMessageType('CreateProcessInstanceWithResultResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPROCESSINSTANCEWITHRESULTRESPONSE,
  '__module__' : 'zeebe_grpc.gateway_pb2'
  # @@protoc_insertion_point(class_scope:gateway_protocol.CreateProcessInstanceWithResultResponse)
  })
_sym_db.RegisterMessage(CreateProcessInstanceWithResultResponse)

DeployProcessRequest = _reflection.GeneratedProtocolMessageType('DeployProcessRequest', (_message.Message,), {
  'DESCRIPTOR' : _DEPLOYPROCESSREQUEST,
  '__module__' : 'zeebe_grpc.gateway_pb2'
  # @@protoc_insertion_point(class_scope:gateway_protocol.DeployProcessRequest)
  })
_sym_db.RegisterMessage(DeployProcessRequest)

ProcessRequestObject = _reflection.GeneratedProtocolMessageType('ProcessRequestObject', (_message.Message,), {
  'DESCRIPTOR' : _PROCESSREQUESTOBJECT,
  '__module__' : 'zeebe_grpc.gateway_pb2'
  # @@protoc_insertion_point(class_scope:gateway_protocol.ProcessRequestObject)
  })
_sym_db.RegisterMessage(ProcessRequestObject)

DeployProcessResponse = _reflection.GeneratedProtocolMessageType('DeployProcessResponse', (_message.Message,), {
  'DESCRIPTOR' : _DEPLOYPROCESSRESPONSE,
  '__module__' : 'zeebe_grpc.gateway_pb2'
  # @@protoc_insertion_point(class_scope:gateway_protocol.DeployProcessResponse)
  })
_sym_db.RegisterMessage(DeployProcessResponse)

DeployResourceRequest = _reflection.GeneratedProtocolMessageType('DeployResourceRequest', (_message.Message,), {
  'DESCRIPTOR' : _DEPLOYRESOURCEREQUEST,
  '__module__' : 'zeebe_grpc.gateway_pb2'
  # @@protoc_insertion_point(class_scope:gateway_protocol.DeployResourceRequest)
  })
_sym_db.RegisterMessage(DeployResourceRequest)

Resource = _reflection.GeneratedProtocolMessageType('Resource', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCE,
  '__module__' : 'zeebe_grpc.gateway_pb2'
  # @@protoc_insertion_point(class_scope:gateway_protocol.Resource)
  })
_sym_db.RegisterMessage(Resource)

DeployResourceResponse = _reflection.GeneratedProtocolMessageType('DeployResourceResponse', (_message.Message,), {
  'DESCRIPTOR' : _DEPLOYRESOURCERESPONSE,
  '__module__' : 'zeebe_grpc.gateway_pb2'
  # @@protoc_insertion_point(class_scope:gateway_protocol.DeployResourceResponse)
  })
_sym_db.RegisterMessage(DeployResourceResponse)

Deployment = _reflection.GeneratedProtocolMessageType('Deployment', (_message.Message,), {
  'DESCRIPTOR' : _DEPLOYMENT,
  '__module__' : 'zeebe_grpc.gateway_pb2'
  # @@protoc_insertion_point(class_scope:gateway_protocol.Deployment)
  })
_sym_db.RegisterMessage(Deployment)

ProcessMetadata = _reflection.GeneratedProtocolMessageType('ProcessMetadata', (_message.Message,), {
  'DESCRIPTOR' : _PROCESSMETADATA,
  '__module__' : 'zeebe_grpc.gateway_pb2'
  # @@protoc_insertion_point(class_scope:gateway_protocol.ProcessMetadata)
  })
_sym_db.RegisterMessage(ProcessMetadata)

DecisionMetadata = _reflection.GeneratedProtocolMessageType('DecisionMetadata', (_message.Message,), {
  'DESCRIPTOR' : _DECISIONMETADATA,
  '__module__' : 'zeebe_grpc.gateway_pb2'
  # @@protoc_insertion_point(class_scope:gateway_protocol.DecisionMetadata)
  })
_sym_db.RegisterMessage(DecisionMetadata)

DecisionRequirementsMetadata = _reflection.GeneratedProtocolMessageType('DecisionRequirementsMetadata', (_message.Message,), {
  'DESCRIPTOR' : _DECISIONREQUIREMENTSMETADATA,
  '__module__' : 'zeebe_grpc.gateway_pb2'
  # @@protoc_insertion_point(class_scope:gateway_protocol.DecisionRequirementsMetadata)
  })
_sym_db.RegisterMessage(DecisionRequirementsMetadata)

FailJobRequest = _reflection.GeneratedProtocolMessageType('FailJobRequest', (_message.Message,), {
  'DESCRIPTOR' : _FAILJOBREQUEST,
  '__module__' : 'zeebe_grpc.gateway_pb2'
  # @@protoc_insertion_point(class_scope:gateway_protocol.FailJobRequest)
  })
_sym_db.RegisterMessage(FailJobRequest)

FailJobResponse = _reflection.GeneratedProtocolMessageType('FailJobResponse', (_message.Message,), {
  'DESCRIPTOR' : _FAILJOBRESPONSE,
  '__module__' : 'zeebe_grpc.gateway_pb2'
  # @@protoc_insertion_point(class_scope:gateway_protocol.FailJobResponse)
  })
_sym_db.RegisterMessage(FailJobResponse)

ThrowErrorRequest = _reflection.GeneratedProtocolMessageType('ThrowErrorRequest', (_message.Message,), {
  'DESCRIPTOR' : _THROWERRORREQUEST,
  '__module__' : 'zeebe_grpc.gateway_pb2'
  # @@protoc_insertion_point(class_scope:gateway_protocol.ThrowErrorRequest)
  })
_sym_db.RegisterMessage(ThrowErrorRequest)

ThrowErrorResponse = _reflection.GeneratedProtocolMessageType('ThrowErrorResponse', (_message.Message,), {
  'DESCRIPTOR' : _THROWERRORRESPONSE,
  '__module__' : 'zeebe_grpc.gateway_pb2'
  # @@protoc_insertion_point(class_scope:gateway_protocol.ThrowErrorResponse)
  })
_sym_db.RegisterMessage(ThrowErrorResponse)

PublishMessageRequest = _reflection.GeneratedProtocolMessageType('PublishMessageRequest', (_message.Message,), {
  'DESCRIPTOR' : _PUBLISHMESSAGEREQUEST,
  '__module__' : 'zeebe_grpc.gateway_pb2'
  # @@protoc_insertion_point(class_scope:gateway_protocol.PublishMessageRequest)
  })
_sym_db.RegisterMessage(PublishMessageRequest)

PublishMessageResponse = _reflection.GeneratedProtocolMessageType('PublishMessageResponse', (_message.Message,), {
  'DESCRIPTOR' : _PUBLISHMESSAGERESPONSE,
  '__module__' : 'zeebe_grpc.gateway_pb2'
  # @@protoc_insertion_point(class_scope:gateway_protocol.PublishMessageResponse)
  })
_sym_db.RegisterMessage(PublishMessageResponse)

ResolveIncidentRequest = _reflection.GeneratedProtocolMessageType('ResolveIncidentRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESOLVEINCIDENTREQUEST,
  '__module__' : 'zeebe_grpc.gateway_pb2'
  # @@protoc_insertion_point(class_scope:gateway_protocol.ResolveIncidentRequest)
  })
_sym_db.RegisterMessage(ResolveIncidentRequest)

ResolveIncidentResponse = _reflection.GeneratedProtocolMessageType('ResolveIncidentResponse', (_message.Message,), {
  'DESCRIPTOR' : _RESOLVEINCIDENTRESPONSE,
  '__module__' : 'zeebe_grpc.gateway_pb2'
  # @@protoc_insertion_point(class_scope:gateway_protocol.ResolveIncidentResponse)
  })
_sym_db.RegisterMessage(ResolveIncidentResponse)

TopologyRequest = _reflection.GeneratedProtocolMessageType('TopologyRequest', (_message.Message,), {
  'DESCRIPTOR' : _TOPOLOGYREQUEST,
  '__module__' : 'zeebe_grpc.gateway_pb2'
  # @@protoc_insertion_point(class_scope:gateway_protocol.TopologyRequest)
  })
_sym_db.RegisterMessage(TopologyRequest)

TopologyResponse = _reflection.GeneratedProtocolMessageType('TopologyResponse', (_message.Message,), {
  'DESCRIPTOR' : _TOPOLOGYRESPONSE,
  '__module__' : 'zeebe_grpc.gateway_pb2'
  # @@protoc_insertion_point(class_scope:gateway_protocol.TopologyResponse)
  })
_sym_db.RegisterMessage(TopologyResponse)

BrokerInfo = _reflection.GeneratedProtocolMessageType('BrokerInfo', (_message.Message,), {
  'DESCRIPTOR' : _BROKERINFO,
  '__module__' : 'zeebe_grpc.gateway_pb2'
  # @@protoc_insertion_point(class_scope:gateway_protocol.BrokerInfo)
  })
_sym_db.RegisterMessage(BrokerInfo)

Partition = _reflection.GeneratedProtocolMessageType('Partition', (_message.Message,), {
  'DESCRIPTOR' : _PARTITION,
  '__module__' : 'zeebe_grpc.gateway_pb2'
  # @@protoc_insertion_point(class_scope:gateway_protocol.Partition)
  })
_sym_db.RegisterMessage(Partition)

UpdateJobRetriesRequest = _reflection.GeneratedProtocolMessageType('UpdateJobRetriesRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEJOBRETRIESREQUEST,
  '__module__' : 'zeebe_grpc.gateway_pb2'
  # @@protoc_insertion_point(class_scope:gateway_protocol.UpdateJobRetriesRequest)
  })
_sym_db.RegisterMessage(UpdateJobRetriesRequest)

UpdateJobRetriesResponse = _reflection.GeneratedProtocolMessageType('UpdateJobRetriesResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEJOBRETRIESRESPONSE,
  '__module__' : 'zeebe_grpc.gateway_pb2'
  # @@protoc_insertion_point(class_scope:gateway_protocol.UpdateJobRetriesResponse)
  })
_sym_db.RegisterMessage(UpdateJobRetriesResponse)

SetVariablesRequest = _reflection.GeneratedProtocolMessageType('SetVariablesRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETVARIABLESREQUEST,
  '__module__' : 'zeebe_grpc.gateway_pb2'
  # @@protoc_insertion_point(class_scope:gateway_protocol.SetVariablesRequest)
  })
_sym_db.RegisterMessage(SetVariablesRequest)

SetVariablesResponse = _reflection.GeneratedProtocolMessageType('SetVariablesResponse', (_message.Message,), {
  'DESCRIPTOR' : _SETVARIABLESRESPONSE,
  '__module__' : 'zeebe_grpc.gateway_pb2'
  # @@protoc_insertion_point(class_scope:gateway_protocol.SetVariablesResponse)
  })
_sym_db.RegisterMessage(SetVariablesResponse)

_GATEWAY = DESCRIPTOR.services_by_name['Gateway']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n!io.camunda.zeebe.gateway.protocolP\000Z\005./;pb'
  _DEPLOYPROCESSREQUEST._options = None
  _DEPLOYPROCESSREQUEST._serialized_options = b'\030\001'
  _PROCESSREQUESTOBJECT._options = None
  _PROCESSREQUESTOBJECT._serialized_options = b'\030\001'
  _DEPLOYPROCESSRESPONSE._options = None
  _DEPLOYPROCESSRESPONSE._serialized_options = b'\030\001'
  _GATEWAY.methods_by_name['DeployProcess']._options = None
  _GATEWAY.methods_by_name['DeployProcess']._serialized_options = b'\210\002\001'
  _ACTIVATEJOBSREQUEST._serialized_start=47
  _ACTIVATEJOBSREQUEST._serialized_end=189
  _ACTIVATEJOBSRESPONSE._serialized_start=191
  _ACTIVATEJOBSRESPONSE._serialized_end=259
  _ACTIVATEDJOB._serialized_start=262
  _ACTIVATEDJOB._serialized_end=558
  _CANCELPROCESSINSTANCEREQUEST._serialized_start=560
  _CANCELPROCESSINSTANCEREQUEST._serialized_end=618
  _CANCELPROCESSINSTANCERESPONSE._serialized_start=620
  _CANCELPROCESSINSTANCERESPONSE._serialized_end=651
  _COMPLETEJOBREQUEST._serialized_start=653
  _COMPLETEJOBREQUEST._serialized_end=708
  _COMPLETEJOBRESPONSE._serialized_start=710
  _COMPLETEJOBRESPONSE._serialized_end=731
  _CREATEPROCESSINSTANCEREQUEST._serialized_start=733
  _CREATEPROCESSINSTANCEREQUEST._serialized_end=852
  _CREATEPROCESSINSTANCERESPONSE._serialized_start=855
  _CREATEPROCESSINSTANCERESPONSE._serialized_end=984
  _CREATEPROCESSINSTANCEWITHRESULTREQUEST._serialized_start=987
  _CREATEPROCESSINSTANCEWITHRESULTREQUEST._serialized_end=1140
  _CREATEPROCESSINSTANCEWITHRESULTRESPONSE._serialized_start=1143
  _CREATEPROCESSINSTANCEWITHRESULTRESPONSE._serialized_end=1301
  _DEPLOYPROCESSREQUEST._serialized_start=1303
  _DEPLOYPROCESSREQUEST._serialized_end=1388
  _PROCESSREQUESTOBJECT._serialized_start=1390
  _PROCESSREQUESTOBJECT._serialized_end=1450
  _DEPLOYPROCESSRESPONSE._serialized_start=1452
  _DEPLOYPROCESSRESPONSE._serialized_end=1546
  _DEPLOYRESOURCEREQUEST._serialized_start=1548
  _DEPLOYRESOURCEREQUEST._serialized_end=1618
  _RESOURCE._serialized_start=1620
  _RESOURCE._serialized_end=1661
  _DEPLOYRESOURCERESPONSE._serialized_start=1663
  _DEPLOYRESOURCERESPONSE._serialized_end=1751
  _DEPLOYMENT._serialized_start=1754
  _DEPLOYMENT._serialized_end=1968
  _PROCESSMETADATA._serialized_start=1970
  _PROCESSMETADATA._serialized_end=2079
  _DECISIONMETADATA._serialized_start=2082
  _DECISIONMETADATA._serialized_end=2254
  _DECISIONREQUIREMENTSMETADATA._serialized_start=2257
  _DECISIONREQUIREMENTSMETADATA._serialized_end=2431
  _FAILJOBREQUEST._serialized_start=2433
  _FAILJOBREQUEST._serialized_end=2526
  _FAILJOBRESPONSE._serialized_start=2528
  _FAILJOBRESPONSE._serialized_end=2545
  _THROWERRORREQUEST._serialized_start=2547
  _THROWERRORREQUEST._serialized_end=2623
  _THROWERRORRESPONSE._serialized_start=2625
  _THROWERRORRESPONSE._serialized_end=2645
  _PUBLISHMESSAGEREQUEST._serialized_start=2647
  _PUBLISHMESSAGEREQUEST._serialized_end=2766
  _PUBLISHMESSAGERESPONSE._serialized_start=2768
  _PUBLISHMESSAGERESPONSE._serialized_end=2805
  _RESOLVEINCIDENTREQUEST._serialized_start=2807
  _RESOLVEINCIDENTREQUEST._serialized_end=2852
  _RESOLVEINCIDENTRESPONSE._serialized_start=2854
  _RESOLVEINCIDENTRESPONSE._serialized_end=2879
  _TOPOLOGYREQUEST._serialized_start=2881
  _TOPOLOGYREQUEST._serialized_end=2898
  _TOPOLOGYRESPONSE._serialized_start=2901
  _TOPOLOGYRESPONSE._serialized_end=3063
  _BROKERINFO._serialized_start=3065
  _BROKERINFO._serialized_end=3187
  _PARTITION._serialized_start=3190
  _PARTITION._serialized_end=3478
  _PARTITION_PARTITIONBROKERROLE._serialized_start=3354
  _PARTITION_PARTITIONBROKERROLE._serialized_end=3415
  _PARTITION_PARTITIONBROKERHEALTH._serialized_start=3417
  _PARTITION_PARTITIONBROKERHEALTH._serialized_end=3478
  _UPDATEJOBRETRIESREQUEST._serialized_start=3480
  _UPDATEJOBRETRIESREQUEST._serialized_end=3538
  _UPDATEJOBRETRIESRESPONSE._serialized_start=3540
  _UPDATEJOBRETRIESRESPONSE._serialized_end=3566
  _SETVARIABLESREQUEST._serialized_start=3568
  _SETVARIABLESREQUEST._serialized_end=3651
  _SETVARIABLESRESPONSE._serialized_start=3653
  _SETVARIABLESRESPONSE._serialized_end=3688
  _GATEWAY._serialized_start=3691
  _GATEWAY._serialized_end=5175
# @@protoc_insertion_point(module_scope)
